KeyCode

Enum KeyCode 

#[non_exhaustive]
pub enum KeyCode {
Show 24 variants Char(char), F(u8), Backspace, Enter, Left, Right, Up, Down, Home, End, PageUp, PageDown, Tab, BackTab, Delete, Insert, Escape, Modifier(ModifierKey), CapsLock, ScrollLock, NumLock, PrintScreen, Pause, Menu,
}
Keyboard key codes.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Char(char)

A character key.



F(u8)

A function key.



Backspace

Backspace.



Enter

Enter.



Left

Left arrow.



Right

Right arrow.



Up

Up arrow.



Down

Down arrow.



Home

Home.



End

End.



PageUp

Page Up.



PageDown

Page Down.



Tab

Tab.



BackTab

Backtab.



Delete

Delete.



Insert

Insert.



Escape

Escape.



Modifier(ModifierKey)

A modifier key pressed on its own, without another key. See ModifierKey for the backend-availability caveat.



CapsLock

Caps Lock.



ScrollLock

Scroll Lock.



NumLock

Num Lock.



PrintScreen

Print Screen.



Pause

Pause.



Menu

Menu (context menu key).