KeyEvent

Struct KeyEvent 

#[non_exhaustive]
pub struct KeyEvent { pub code: KeyCode, pub modifiers: KeyModifiers, pub kind: KeyEventKind, pub location: KeyLocation, }
Keyboard input event.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
code: KeyCode

The key code.

modifiers: KeyModifiers

Modifiers held down during the event.

kind: KeyEventKind

Whether this is a press, auto-repeat, or release.

Backends that cannot distinguish these always report KeyEventKind::Press. See KeyEventKind for per-backend behavior.

location: KeyLocation

The physical location of the key, for keys that appear in more than one place.

Backends that cannot determine this always report KeyLocation::Standard.

Implementations

Source

impl KeyEvent

pub const fn new(code: KeyCode, modifiers: KeyModifiers) -> Self

Creates a key press event with the given code and modifiers, and KeyLocation::Standard.

pub const fn with_kind( code: KeyCode, modifiers: KeyModifiers, kind: KeyEventKind, ) -> Self

Creates a key event with an explicit KeyEventKind and KeyLocation::Standard.

pub const fn with_location( code: KeyCode, modifiers: KeyModifiers, kind: KeyEventKind, location: KeyLocation, ) -> Self

Creates a key event with an explicit KeyEventKind and KeyLocation.

pub const fn is_down(self) -> bool

Returns true if this event is a press or auto-repeat (i.e. the key is down), and false for a release.